from typing import Optional

from pipeline.schemas.base import BaseModel
from pipeline.schemas.pipeline import PipelineGet
from pipeline.schemas.project import ProjectGet


class DeploymentCreate(BaseModel):
    """Schema for creating a pipeline deployment"""

    pipeline_id: str
    # If not provided, deployment will be created with users' default project
    project_id: Optional[str] = None


class DeploymentGet(BaseModel):
    id: str
    pipeline: PipelineGet
    project: ProjectGet
    active: bool


class DeploymentPatch(BaseModel):
    active: Optional[bool]



from .base import BaseModel


class OrganisationMemberInviteBase(BaseModel):
    #: The ID of the Organisation the invite relates to
    organisation_id: str
    #: The email the invite is to be sent to
    email: str


class OrganisationMemberInviteCreate(OrganisationMemberInviteBase):
    """Create an invitation to join an Organisation."""

    pass


class OrganisationMemberInviteGet(OrganisationMemberInviteBase):
    """View of an invitation to join an Organisation."""

    #: The ID of this invite
    id: str
    #: If True this invite has been accepted (emailed link has been visited)
    accepted: bool
    #: If True the invitation has been linked with an existing User
    has_user: bool



from typing import Optional

from .base import AvatarHolder, Patchable


class ProjectBase(AvatarHolder):
    name: str


class ProjectCreate(ProjectBase):
    pass


class ProjectGet(ProjectBase):
    id: str


class ProjectGetDetailed(ProjectGet):
    """Include counts of 'held' resources."""

    n_functions: int
    n_pipelines: int
    n_models: int
    n_function_runs: int
    n_pipeline_runs: int
    n_data: int

    class Config:
        orm_mode = False


class ProjectPatch(ProjectBase, Patchable):
    name: Optional[str]



from typing import Optional

from .base import AvatarHolder, Patchable


class OrganisationBase(AvatarHolder):
    name: str


class OrganisationGet(OrganisationBase):
    id: str
    member_count: int


class OrganisationCreate(OrganisationBase):
    pass


class OrganisationPatch(OrganisationBase, Patchable):
    name: Optional[str]



from pydantic import Field

from .base import AvatarHolder, BaseModel, Patchable


class OrganisationMemberBase(BaseModel):
    email: str


class OrganisationMemberCreate(OrganisationMemberBase):
    pass


class OrganisationMemberUserGet(AvatarHolder):
    id: str
    email: str
    username: str


class OrganisationMemberGet(BaseModel):
    organisation_id: str
    role: str = Field(alias="role_name")
    user: OrganisationMemberUserGet


class OrganisationMemberPatch(Patchable):
    role: str



class NonChargeableProfile(Exception):
    def __init__(self, project_id=None, message="Non chargeable user profile") -> None:
        self.project_id = project_id
        self.message = message
        super().__init__(self.message)

    def __str__(self):
        return f"{self.project_id} -> {self.message}"
